#from django.contrib.auth.decorators import login_required
#from django.shortcuts import render_to_response
#from django.shortcuts import get_object_or_404
#from django.template import RequestContext
#from django.shortcuts import redirect
#from django.template.defaultfilters import slugify
#from django.core.urlresolvers import reverse
#from django.http import Http404
#from django.http import HttpResponseForbidden
#from django.http import HttpResponseServerError
#from django.http import HttpResponseRedirect

# class YourView(TemplateView):
#    template_name = 'sessioninfo/default.html'