
    {% comment %}
        As the developer of this package, don't place anything here if you can help it
        since this allows developers to have interoperability between your template
        structure and their own.

        Example: Developer melding the 2SoD pattern to fit inside with another pattern::

            {% extends "base.html" %}
            {% load static %}

            <!-- Their site uses old school block layout -->
            {% block extra_js %}

                <!-- Your package using 2SoD block layout -->
                {% block javascript %}
                    <script src="{#% static 'js/ninja.js' %#}" type="text/javascript"></script>
                {% endblock javascript %}

            {% endblock extra_js %}
    {% endcomment %}
