# -*- coding: utf-8 -*-

"""Models for the sessioninfo app."""

# from django.db import models
# from django.utils.translation import ugettext_lazy as _
# from django.utils.encoding import python_2_unicode_compatible


"""
@python_2_unicode_compatible
class Item(models.Model):
    name = models.CharField(max_length=100)
    items = models.ManyToManyField('self', blank=True)
    private = models.BooleanField(default=True)

    class Meta:
        verbose_name = 'Item'
        verbose_name_plural = 'Items'

    def __str__(self):
        return self.name
"""