"""URLs for the sessioninfo app."""

# from django.conf.urls import patterns, url

# from sessioninfo import views


# urlpatterns = patterns(
#     '',
#     url(r'^$',
#         views.YourView.as_view(),
#         name='sessioninfo_default'),
# )